"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _postcss = require("../utils/postcss");

var _removeDashAmpersand = _interopRequireDefault(require("../plugins/remove-dash-ampersand"));

var _removeEmptyRules = _interopRequireDefault(require("../plugins/remove-empty-rules"));

var _removeNestedUnusedDollarVars = _interopRequireDefault(require("../plugins/remove-nested-unused-dollar-vars"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const command = "union-class-name <files...>";
exports.command = command;
const describe = "Promotes union class rules to the parent level to improve grepability";
exports.describe = describe;
const builder = {
  r: {
    alias: "reorder",
    describe: "reorder promoted rules rules ",
    choices: ["no-reorder", "safe-reorder", "unsafe-reorder"],
    default: "no-reorder"
  },
  p: {
    alias: "promote-dollar-vars",
    describe: "promote dollar vars to global scope",
    choices: ["no-global", "global"],
    default: "global"
  },
  n: {
    alias: "namespace-dollar-vars",
    describe: "namespace promoted dollar vars",
    choices: ["no-namespace", "namespace-when-necessary", "namespace-always"],
    default: "no-namespace"
  }
};
exports.builder = builder;

const handler = argv => {
  return (0, _postcss.processFiles)(argv.files, (0, _postcss.createProcessor)([(0, _removeDashAmpersand.default)({
    reorder: argv.reorder,
    promoteDollarVars: argv.promoteDollarVars,
    namespaceDollarVars: argv.namespaceDollarVars
  }), (0, _removeNestedUnusedDollarVars.default)(), (0, _removeEmptyRules.default)()]));
};

exports.handler = handler;